@@ -45,25 +45,24 @@
 #define REDUCE_RATE 0.95
 #define NUM_ATTEMPT 100
 
-static Cell *trim_cell(int *mapping_table,
-                       SPGCONST double trimmed_lattice[3][3], const Cell *cell,
-                       const double symprec);
+static Cell *trim_cell(int *mapping_table, const double trimmed_lattice[3][3],
+                       const Cell *cell, const double symprec);
 static void set_positions_and_tensors(Cell *trimmed_cell,
                                       const VecDBL *position,
                                       const SiteTensorType tensor_rank,
                                       const double *tensors,
                                       const int *mapping_table,
                                       const int *overlap_table);
-static VecDBL *translate_atoms_in_trimmed_lattice(
-    const Cell *cell, SPGCONST double prim_lat[3][3]);
+static VecDBL *translate_atoms_in_trimmed_lattice(const Cell *cell,
+                                                  const int tmat_p_i[3][3]);
 static int *get_overlap_table(const VecDBL *position, const int cell_size,
                               const int *cell_types, const Cell *trimmed_cell,
                               const double symprec);
 
 // @brief Allocate Cell. NULL is returned if failed
 // @param size number of atoms
-// @param tensor_rank rank of site tensors for magnetic symmetry. Set -1 if not
-// used.
+// @param tensor_rank rank of site tensors for magnetic symmetry. Set -1 if
+// not used.
 Cell *cel_alloc_cell(const int size, const SiteTensorType tensor_rank) {
     Cell *cell;
 
@@ -132,7 +131,8 @@ void cel_free_cell(Cell *cell) {
             cell->types = NULL;
         }
         if ((cell->tensor_rank != NOSPIN) && (cell->tensors != NULL)) {
-            // When cell->tensor_rank==NOSPIN, cell->tensors is already NULL.
+            // When cell->tensor_rank==NOSPIN, cell->tensors is already
+            // NULL.
             free(cell->tensors);
             cell->tensors = NULL;
         }
@@ -140,8 +140,8 @@ void cel_free_cell(Cell *cell) {
     }
 }
 
-void cel_set_cell(Cell *cell, SPGCONST double lattice[3][3],
-                  SPGCONST double position[][3], const int types[]) {
+void cel_set_cell(Cell *cell, const double lattice[3][3],
+                  const double position[][3], const int types[]) {
     int i, j;
     mat_copy_matrix_d3(cell->lattice, lattice);
     for (i = 0; i < cell->size; i++) {
@@ -153,8 +153,8 @@ void cel_set_cell(Cell *cell, SPGCONST double lattice[3][3],
 }
 
 /* aperiodic_axis = -1 for none; = 0 1 2 for a b c */
-void cel_set_layer_cell(Cell *cell, SPGCONST double lattice[3][3],
-                        SPGCONST double position[][3], const int types[],
+void cel_set_layer_cell(Cell *cell, const double lattice[3][3],
+                        const double position[][3], const int types[],
                         const int aperiodic_axis) {
     int i, j;
     mat_copy_matrix_d3(cell->lattice, lattice);
@@ -172,8 +172,8 @@ void cel_set_layer_cell(Cell *cell, SPGCONST double lattice[3][3],
     cell->aperiodic_axis = aperiodic_axis;
 }
 
-void cel_set_cell_with_tensors(Cell *cell, SPGCONST double lattice[3][3],
-                               SPGCONST double position[][3], const int types[],
+void cel_set_cell_with_tensors(Cell *cell, const double lattice[3][3],
+                               const double position[][3], const int types[],
                                const double *tensors) {
     int i, j;
 
@@ -212,7 +212,7 @@ Cell *cel_copy_cell(const Cell *cell) {
 }
 
 int cel_is_overlap(const double a[3], const double b[3],
-                   SPGCONST double lattice[3][3], const double symprec) {
+                   const double lattice[3][3], const double symprec) {
     int i;
     double v_diff[3];
 
@@ -231,7 +231,7 @@ int cel_is_overlap(const double a[3], const double b[3],
 
 int cel_is_overlap_with_same_type(const double a[3], const double b[3],
                                   const int type_a, const int type_b,
-                                  SPGCONST double lattice[3][3],
+                                  const double lattice[3][3],
                                   const double symprec) {
     if (type_a == type_b) {
         return cel_is_overlap(a, b, lattice, symprec);
@@ -276,8 +276,8 @@ int cel_any_overlap_with_same_type(const Cell *cell, const double symprec) {
 /* Modified from cel_is_overlap */
 /* Periodic boundary condition only applied on 2 directions */
 int cel_layer_is_overlap(const double a[3], const double b[3],
-                         SPGCONST double lattice[3][3],
-                         const int periodic_axes[2], const double symprec) {
+                         const double lattice[3][3], const int periodic_axes[2],
+                         const double symprec) {
     double v_diff[3];
 
     v_diff[0] = a[0] - b[0];
@@ -297,7 +297,7 @@ int cel_layer_is_overlap(const double a[3], const double b[3],
 
 int cel_layer_is_overlap_with_same_type(const double a[3], const double b[3],
                                         const int type_a, const int type_b,
-                                        SPGCONST double lattice[3][3],
+                                        const double lattice[3][3],
                                         const int periodic_axes[2],
                                         const double symprec) {
     if (type_a == type_b) {
@@ -326,21 +326,22 @@ int cel_layer_any_overlap_with_same_type(const Cell *cell,
     return 0;
 }
 
-/// @param[out] mapping_table array (cell->size, ), maps atom-`i` in cell to
-/// non-overlapped atom-`mapping_table[i]`
-/// @param[in] trimmed_lattice
-/// @param[in] cell
-/// @param[in] symprec
-/// @return trimmed_cell
-Cell *cel_trim_cell(int *mapping_table, SPGCONST double trimmed_lattice[3][3],
+/// @param[out] mapping_table array (`cell->size`, ), maps atom-`i` in `cell` to
+/// atom-`j` in smaller cell to be returned.
+/// @param[in] trimmed_lattice basis vectors of smaller cell which are
+/// commensure with basis vectors of larger cell.
+/// @param[in] cell larger cell from which smaller cell having basis vectors of
+/// `trimmed_lattice` is created.
+/// @param[in] symprec tolerance parameter.
+/// @return smaller cell having basis vectors of `trimmed_lattice`.
+Cell *cel_trim_cell(int *mapping_table, const double trimmed_lattice[3][3],
                     const Cell *cell, const double symprec) {
     return trim_cell(mapping_table, trimmed_lattice, cell, symprec);
 }
 
 /* Return NULL if failed */
-static Cell *trim_cell(int *mapping_table,
-                       SPGCONST double trimmed_lattice[3][3], const Cell *cell,
-                       const double symprec) {
+static Cell *trim_cell(int *mapping_table, const double trimmed_lattice[3][3],
+                       const Cell *cell, const double symprec) {
     int i, index_atom, ratio;
     Cell *trimmed_cell;
     VecDBL *position;
@@ -380,8 +381,8 @@ static Cell *trim_cell(int *mapping_table,
         goto err;
     }
 
-    if ((position = translate_atoms_in_trimmed_lattice(
-             cell, trimmed_lattice)) == NULL) {
+    if ((position = translate_atoms_in_trimmed_lattice(cell, tmp_mat_int)) ==
+        NULL) {
         warning_print("spglib: translate_atoms_in_trimmed_lattice failed.\n");
         warning_print(" (line %d, %s).\n", __LINE__, __FILE__);
         cel_free_cell(trimmed_cell);
@@ -504,10 +505,9 @@ static void set_positions_and_tensors(Cell *trimmed_cell,
 }
 
 /* Return NULL if failed */
-static VecDBL *translate_atoms_in_trimmed_lattice(
-    const Cell *cell, SPGCONST double trimmed_lattice[3][3]) {
+static VecDBL *translate_atoms_in_trimmed_lattice(const Cell *cell,
+                                                  const int tmat_p_i[3][3]) {
     int i, j;
-    double tmp_matrix[3][3], axis_inv[3][3];
     VecDBL *position;
 
     position = NULL;
@@ -516,13 +516,10 @@ static VecDBL *translate_atoms_in_trimmed_lattice(
         return NULL;
     }
 
-    mat_inverse_matrix_d3(tmp_matrix, trimmed_lattice, 0);
-    mat_multiply_matrix_d3(axis_inv, tmp_matrix, cell->lattice);
-
     /* Send atoms into the trimmed cell */
     for (i = 0; i < cell->size; i++) {
-        mat_multiply_matrix_vector_d3(position->vec[i], axis_inv,
-                                      cell->position[i]);
+        mat_multiply_matrix_vector_id3(position->vec[i], tmat_p_i,
+                                       cell->position[i]);
         for (j = 0; j < 3; j++) {
             if (j != cell->aperiodic_axis) {
                 position->vec[i][j] = mat_Dmod1(position->vec[i][j]);
@@ -533,7 +530,17 @@ static VecDBL *translate_atoms_in_trimmed_lattice(
     return position;
 }
 
-/* Return NULL if failed */
+/// @brief Find translationally equivalent atoms in larger cell with respect to
+/// lattice of smaller cell.
+/// @param position array of positions of atoms in larger cells that are reduced
+/// in smaller cells.
+/// @param cell_size number of atoms in larger cell.
+/// @param cell_types yypes of atoms in larger cell.
+/// @param trimmed_cell basis vectors of smaller cell.
+/// @param symprec tolerance parameter.
+/// @return array (cell_size, ) If `position[i]` and `position[j]` with `i` <=
+/// `j` are equivalent, `overlap_table[i]` = `overlap_table[j]` = `i`. Return
+/// NULL if failed.
 static int *get_overlap_table(const VecDBL *position, const int cell_size,
                               const int *cell_types, const Cell *trimmed_cell,
                               const double symprec) {
