@@ -34,29 +34,27 @@
 
 #include "delaunay.h"
 
+#include <assert.h>
+#include <limits.h>
 #include <stdio.h>
 #include <stdlib.h>
 
 #include "debug.h"
 #include "mathfunc.h"
 
-#define NUM_ATTEMPT 100
 #define ZERO_PREC 1e-10
 
-static int delaunay_reduce(double red_lattice[3][3],
-                           SPGCONST double lattice[3][3],
-                           const int aperiodic_axis, SPGCONST double symprec);
+static int get_num_attempts();
+
+static int delaunay_reduce(double red_lattice[3][3], const double lattice[3][3],
+                           const int aperiodic_axis, const double symprec);
 static int delaunay_reduce_basis(double basis[4][3], const int lattice_rank,
                                  const double symprec);
 static void get_delaunay_shortest_vectors(double basis[4][3],
                                           const int lattice_rank,
                                           const double symprec);
-static int get_extended_basis(double basis[4][3], SPGCONST double lattice[3][3],
+static int get_extended_basis(double basis[4][3], const double lattice[3][3],
                               const int aperiodic_axis);
-static int delaunay_reduce_2D(double red_lattice[3][3],
-                              SPGCONST double lattice[3][3],
-                              const int unique_axis, const int aperiodic_axis,
-                              const double symprec);
 static int delaunay_reduce_basis_2D(double basis[3][3], const int lattice_rank,
                                     const double symprec);
 static void get_delaunay_shortest_vectors_2D(double basis[3][3],
@@ -64,36 +62,36 @@ static void get_delaunay_shortest_vectors_2D(double basis[3][3],
                                              const int lattice_rank,
                                              const double symprec);
 static void get_extended_basis_2D(double basis[3][3],
-                                  SPGCONST double lattice[3][2]);
+                                  const double lattice[3][2]);
+
+int get_num_attempts() {
+    const char *num_attempts_str = getenv("SPGLIB_NUM_ATTEMPTS");
+    if (num_attempts_str != NULL) {
+        // Try to parse the string as an integer
+        char *end;
+        long num_attempts = strtol(num_attempts_str, &end, 10);
+        // If conversion fails end == num_attempts_str
+        if (end != num_attempts_str && num_attempts > 0 &&
+            num_attempts < INT_MAX)
+            return (int)num_attempts;
+        warning_print("Could not parse SPGLIB_NUM_ATTEMPTS=%s\n",
+                      num_attempts_str);
+    }
+    // Otherwise return default number of attempts
+    return 1000;
+}
 
 /* Return 0 if failed */
-int del_delaunay_reduce(double min_lattice[3][3], SPGCONST double lattice[3][3],
+int del_delaunay_reduce(double min_lattice[3][3], const double lattice[3][3],
                         const double symprec) {
     debug_print("del_delaunay_reduce (tolerance = %f):\n", symprec);
 
     return delaunay_reduce(min_lattice, lattice, -1, symprec);
 }
 
-int del_delaunay_reduce_2D(double min_lattice[3][3],
-                           SPGCONST double lattice[3][3], const int unique_axis,
-                           const double symprec) {
-    debug_print("del_delaunay_reduce_2D:\n");
-    return delaunay_reduce_2D(min_lattice, lattice, unique_axis, -1, symprec);
-}
-
-int del_layer_delaunay_reduce_2D(double min_lattice[3][3],
-                                 SPGCONST double lattice[3][3],
-                                 const int unique_axis,
-                                 const int aperiodic_axis,
-                                 const double symprec) {
-    debug_print("del_layer_delaunay_reduce_2D:\n");
-    return delaunay_reduce_2D(min_lattice, lattice, unique_axis, aperiodic_axis,
-                              symprec);
-}
-
 /* Return 0 if failed */
 int del_layer_delaunay_reduce(double min_lattice[3][3],
-                              SPGCONST double lattice[3][3],
+                              const double lattice[3][3],
                               const int aperiodic_axis, const double symprec) {
     debug_print("del_layer_delaunay_reduce (tolerance = %f):\n", symprec);
 
@@ -103,10 +101,9 @@ int del_layer_delaunay_reduce(double min_lattice[3][3],
 /* Delaunay reduction */
 /* Reference can be found in International table A. */
 /* Return 0 if failed */
-static int delaunay_reduce(double red_lattice[3][3],
-                           SPGCONST double lattice[3][3],
+static int delaunay_reduce(double red_lattice[3][3], const double lattice[3][3],
                            const int aperiodic_axis, const double symprec) {
-    int i, j, attempt, succeeded, lattice_rank;
+    int succeeded, lattice_rank;
     int tmp_mat_int[3][3];
     double volume;
     double orig_lattice[3][3], tmp_mat[3][3], basis[4][3];
@@ -115,7 +112,10 @@ static int delaunay_reduce(double red_lattice[3][3],
 
     lattice_rank = get_extended_basis(basis, lattice, aperiodic_axis);
 
-    for (attempt = 0; attempt < NUM_ATTEMPT; attempt++) {
+    for (int attempt = 0, max_attempt = get_num_attempts();
+         attempt < max_attempt; attempt++) {
+        debug_print("Trying delaunay_reduce_basis: attempt %d/%d\n", attempt,
+                    get_num_attempts());
         succeeded = delaunay_reduce_basis(basis, lattice_rank, symprec);
         if (succeeded) {
             break;
@@ -128,15 +128,15 @@ static int delaunay_reduce(double red_lattice[3][3],
 
     get_delaunay_shortest_vectors(basis, lattice_rank, symprec);
 
-    for (i = 0; i < 3; i++) {
-        for (j = 0; j < 3; j++) {
+    for (int i = 0; i < 3; i++) {
+        for (int j = 0; j < 3; j++) {
             red_lattice[i][j] = basis[j][i];
         }
     }
     /* move the aperiodic axis from b3 back to its original direction */
     if (lattice_rank == 2 && aperiodic_axis != 2) {
-        for (i = 0; i < 3; i++) {
-            for (j = 0; j < 3; j++) {
+        for (int i = 0; i < 3; i++) {
+            for (int j = 0; j < 3; j++) {
                 if (j == aperiodic_axis) {
                     red_lattice[i][j] = basis[2][i];
                     red_lattice[i][2] = basis[j][i];
@@ -154,8 +154,8 @@ static int delaunay_reduce(double red_lattice[3][3],
 
     if (volume < 0) {
         /* Flip axes */
-        for (i = 0; i < 3; i++) {
-            for (j = 0; j < 3; j++) {
+        for (int i = 0; i < 3; i++) {
+            for (int j = 0; j < 3; j++) {
                 red_lattice[i][j] = -red_lattice[i][j];
             }
         }
@@ -178,6 +178,9 @@ err:
     return 0;
 }
 
+// @brief Search the shortest vectors from the Delaunay set. If aperiodic axis
+//        exists, find the shortest two vectors inside period plane and the
+//        shortest one outside.
 static void get_delaunay_shortest_vectors(double basis[4][3],
                                           const int lattice_rank,
                                           const double symprec) {
@@ -227,11 +230,10 @@ static void get_delaunay_shortest_vectors(double basis[4][3],
                 }
             }
         }
-        /* find the shortest 2 vectors inside period plane and the shortest one
-         * outside */
     } else {
-        for (i = 0; i < 2; i++) {
-            for (j = 0; j < 2; j++) {
+        // Sort among {b1, b2, b1 + b}
+        for (i = 0; i <= 1; i++) {
+            for (j = 0; j <= 1; j++) {
                 if (mat_norm_squared_d3(b[j]) >
                     mat_norm_squared_d3(b[j + 1]) + ZERO_PREC) {
                     mat_copy_vector_d3(tmpvec, b[j]);
@@ -240,8 +242,13 @@ static void get_delaunay_shortest_vectors(double basis[4][3],
                 }
             }
         }
-        for (i = 3; i < 6; i++) {
-            for (j = 3; j < 6; j++) {
+        // Sort among {b3, b4, b2+b3, b3+b1}
+        // TODO: Is this part required?
+        //       - b4 > b3 because b4 = -(b1+b2+b3) and dot(d3, b1+b2) = 0
+        //       - b2+b3 > b3 because dot(b3, b2) = 0
+        //       - b3+b1 > b3 because dot(b3, b1) = 0
+        for (i = 3; i <= 5; i++) {
+            for (j = 3; j <= 5; j++) {
                 if (mat_norm_squared_d3(b[j]) >
                     mat_norm_squared_d3(b[j + 1]) + ZERO_PREC) {
                     mat_copy_vector_d3(tmpvec, b[j]);
@@ -252,7 +259,7 @@ static void get_delaunay_shortest_vectors(double basis[4][3],
         }
     }
 
-    /* for layer, i = 2, |tmpmat| = 0 is automatically dropped */
+    // For layer, |tmpmat| != 0 for i=2 never happen
     for (i = 2; i < 7; i++) {
         for (j = 0; j < 3; j++) {
             tmpmat[j][0] = b[0][j];
@@ -265,11 +272,13 @@ static void get_delaunay_shortest_vectors(double basis[4][3],
                 basis[1][j] = b[1][j];
                 basis[2][j] = b[i][j];
             }
-            break;
+            return;
         }
     }
 }
 
+// If `lattice_rank==2`, assume `basis[2]` (b3) is along aperiodic axis.
+// TODO: Change `lattice_rank` to a more informative variable
 static int delaunay_reduce_basis(double basis[4][3], const int lattice_rank,
                                  const double symprec) {
     int i, j, k, l;
@@ -295,6 +304,7 @@ static int delaunay_reduce_basis(double basis[4][3], const int lattice_rank,
                     }
                     return 0;
                 } else {
+                    // Here, lattice_rank==2 and dot(b3, b4) > 0
                     /* For layer, if b3 lies in a sphere with center -(b1+b2)/2
                      * and radius |b1+b2|/2, */
                     /* dot(b3, b4) <= 0 will be impossible. This should not
@@ -314,8 +324,10 @@ static int delaunay_reduce_basis(double basis[4][3], const int lattice_rank,
     return 1;
 }
 
-/* aperiodic_axis (if exists) is temporarily moved to b3 */
-static int get_extended_basis(double basis[4][3], SPGCONST double lattice[3][3],
+// @brief Get extended basis for three-dimensional Delaunay reduction.
+//        If exists, `aperiodic_axis` is temporarily moved to b3 (`basis[2]`).
+// @return lattice_rank Rank of `lattice`
+static int get_extended_basis(double basis[4][3], const double lattice[3][3],
                               const int aperiodic_axis) {
     int i, j, lattice_rank;
 
@@ -349,21 +361,21 @@ static int get_extended_basis(double basis[4][3], SPGCONST double lattice[3][3],
     return lattice_rank;
 }
 
-/* For Monocli/Oblique, unique axis is aperiodic axis, j and k are periodic */
-/* For Monocli/Rectang, k is aperiodic axis, unique axis and j are periodic */
-/* j and k are delaunay reduced, which can be incomplete for Monocli/Rectang */
-static int delaunay_reduce_2D(double red_lattice[3][3],
-                              SPGCONST double lattice[3][3],
-                              const int unique_axis, const int aperiodic_axis,
-                              const double symprec) {
-    int i, j, k, attempt, succeeded, lattice_rank;
+int del_layer_delaunay_reduce_2D(double red_lattice[3][3],
+                                 const double lattice[3][3],
+                                 const int unique_axis,
+                                 const int aperiodic_axis,
+                                 const double symprec) {
+    int succeeded, lattice_rank;
     double volume;
     double basis[3][3], lattice_2D[3][2], unique_vec[3];
 
+    debug_print("del_layer_delaunay_reduce_2D:\n");
+
+    int j = -1, k = -1;
     if (aperiodic_axis == -1 || unique_axis == aperiodic_axis) {
-        j = -1;
-        k = -1;
-        for (i = 0; i < 3; i++) {
+        // bulk or Monoclinic/oblique
+        for (int i = 0; i < 3; i++) {
             if (i != unique_axis) {
                 if (j == -1) {
                     j = i;
@@ -374,7 +386,8 @@ static int delaunay_reduce_2D(double red_lattice[3][3],
         }
         lattice_rank = 2;
     } else {
-        for (i = 0; i < 3; i++) {
+        // Monoclinic/rectangular
+        for (int i = 0; i < 3; i++) {
             if (i != unique_axis && i != aperiodic_axis) {
                 j = i;
             }
@@ -383,7 +396,10 @@ static int delaunay_reduce_2D(double red_lattice[3][3],
         lattice_rank = 1;
     }
 
-    for (i = 0; i < 3; i++) {
+    assert(j >= 0);
+    assert(k >= 0);
+
+    for (int i = 0; i < 3; i++) {
         unique_vec[i] = lattice[i][unique_axis];
         lattice_2D[i][0] = lattice[i][j];
         lattice_2D[i][1] = lattice[i][k];
@@ -391,7 +407,10 @@ static int delaunay_reduce_2D(double red_lattice[3][3],
 
     get_extended_basis_2D(basis, lattice_2D);
 
-    for (attempt = 0; attempt < NUM_ATTEMPT; attempt++) {
+    for (int attempt = 0, max_attempt = get_num_attempts();
+         attempt < max_attempt; attempt++) {
+        debug_print("Trying delaunay_reduce_basis_2D: attempt %d/%d\n", attempt,
+                    get_num_attempts());
         succeeded = delaunay_reduce_basis_2D(basis, lattice_rank, symprec);
         if (succeeded) {
             break;
@@ -404,9 +423,8 @@ static int delaunay_reduce_2D(double red_lattice[3][3],
 
     get_delaunay_shortest_vectors_2D(basis, unique_vec, lattice_rank, symprec);
 
-    for (i = 0; i < 3; i++) {
+    for (int i = 0; i < 3; i++) {
         red_lattice[i][unique_axis] = lattice[i][unique_axis];
-        ;
         red_lattice[i][j] = basis[0][i];
         red_lattice[i][k] = basis[1][i];
     }
@@ -419,7 +437,7 @@ static int delaunay_reduce_2D(double red_lattice[3][3],
     }
 
     if (volume < 0) {
-        for (i = 0; i < 3; i++) {
+        for (int i = 0; i < 3; i++) {
             red_lattice[i][unique_axis] = -red_lattice[i][unique_axis];
         }
     }
@@ -520,7 +538,7 @@ static void get_delaunay_shortest_vectors_2D(double basis[3][3],
 }
 
 static void get_extended_basis_2D(double basis[3][3],
-                                  SPGCONST double lattice[3][2]) {
+                                  const double lattice[3][2]) {
     int i, j;
 
     for (i = 0; i < 2; i++) {
