@@ -41,15 +41,14 @@
 #include "spacegroup.h"
 
 typedef struct {
-  Primitive *primitive;
-  Spacegroup *spacegroup;
-  ExactStructure *exact_structure;
+    Primitive *primitive;
+    Spacegroup *spacegroup;
+    ExactStructure *exact_structure;
 } DataContainer;
 
-DataContainer * det_determine_all(const Cell * cell,
-                                  const int hall_number,
-                                  const double symprec,
-                                  const double angle_symprec);
-void det_free_container(DataContainer * container);
+DataContainer *det_determine_all(const Cell *cell, const int hall_number,
+                                 const double symprec,
+                                 const double angle_symprec);
+void det_free_container(DataContainer *container);
 
 #endif
