@@ -40,7 +40,7 @@
 #include "symmetry.h"
 
 int hal_match_hall_symbol_db(double origin_shift[3],
-                             SPGCONST double bravais_lattice[3][3],
+                             const double bravais_lattice[3][3],
                              const int hall_number, const Centering centering,
                              const Symmetry *symmetry, const double symprec);
 
