@@ -82,7 +82,7 @@ static MatINT *get_point_group_reciprocal(const MatINT *rotations,
 static MatINT *get_point_group_reciprocal_with_q(const MatINT *rot_reciprocal,
                                                  const double symprec,
                                                  const size_t num_q,
-                                                 SPGCONST double qpoints[][3]);
+                                                 const double qpoints[][3]);
 static size_t get_dense_ir_reciprocal_mesh(int grid_address[][3],
                                            size_t ir_mapping_table[],
                                            const int mesh[3],
@@ -97,13 +97,10 @@ static size_t get_dense_ir_reciprocal_mesh_distortion(
     int grid_address[][3], size_t ir_mapping_table[], const int mesh[3],
     const int is_shift[3], const MatINT *rot_reciprocal);
 static size_t get_dense_num_ir(size_t ir_mapping_table[], const int mesh[3]);
-static size_t relocate_dense_BZ_grid_address(int bz_grid_address[][3],
-                                             size_t bz_map[],
-                                             SPGCONST int grid_address[][3],
-                                             const int mesh[3],
-                                             SPGCONST double rec_lattice[3][3],
-                                             const int is_shift[3]);
-static double get_tolerance_for_BZ_reduction(SPGCONST double rec_lattice[3][3],
+static size_t relocate_dense_BZ_grid_address(
+    int bz_grid_address[][3], size_t bz_map[], const int grid_address[][3],
+    const int mesh[3], const double rec_lattice[3][3], const int is_shift[3]);
+static double get_tolerance_for_BZ_reduction(const double rec_lattice[3][3],
                                              const int mesh[3]);
 static int check_mesh_symmetry(const int mesh[3], const int is_shift[3],
                                const MatINT *rot_reciprocal);
@@ -138,7 +135,7 @@ int kpt_get_irreducible_reciprocal_mesh(int grid_address[][3],
     num_ir = kpt_get_dense_irreducible_reciprocal_mesh(
         grid_address, dense_ir_mapping_table, mesh, is_shift, rot_reciprocal);
 
-    for (i = 0; i < mesh[0] * mesh[1] * mesh[2]; i++) {
+    for (i = 0; i < (size_t)(mesh[0] * mesh[1] * mesh[2]); i++) {
         ir_mapping_table[i] = dense_ir_mapping_table[i];
     }
 
@@ -164,7 +161,7 @@ size_t kpt_get_dense_irreducible_reciprocal_mesh(int grid_address[][3],
 int kpt_get_stabilized_reciprocal_mesh(
     int grid_address[][3], int ir_mapping_table[], const int mesh[3],
     const int is_shift[3], const int is_time_reversal, const MatINT *rotations,
-    const size_t num_q, SPGCONST double qpoints[][3]) {
+    const size_t num_q, const double qpoints[][3]) {
     int num_ir;
     size_t i;
     size_t *dense_ir_mapping_table;
@@ -179,7 +176,7 @@ int kpt_get_stabilized_reciprocal_mesh(
         grid_address, dense_ir_mapping_table, mesh, is_shift, is_time_reversal,
         rotations, num_q, qpoints);
 
-    for (i = 0; i < mesh[0] * mesh[1] * mesh[2]; i++) {
+    for (i = 0; i < (size_t)(mesh[0] * mesh[1] * mesh[2]); i++) {
         ir_mapping_table[i] = dense_ir_mapping_table[i];
     }
 
@@ -192,7 +189,7 @@ int kpt_get_stabilized_reciprocal_mesh(
 size_t kpt_get_dense_stabilized_reciprocal_mesh(
     int grid_address[][3], size_t ir_mapping_table[], const int mesh[3],
     const int is_shift[3], const int is_time_reversal, const MatINT *rotations,
-    const size_t num_q, SPGCONST double qpoints[][3]) {
+    const size_t num_q, const double qpoints[][3]) {
     size_t num_ir;
     MatINT *rot_reciprocal, *rot_reciprocal_q;
     double tolerance;
@@ -215,10 +212,12 @@ size_t kpt_get_dense_stabilized_reciprocal_mesh(
     return num_ir;
 }
 
-void kpt_get_dense_grid_points_by_rotations(
-    size_t rot_grid_points[], const int address_orig[3],
-    SPGCONST int (*rot_reciprocal)[3][3], const int num_rot, const int mesh[3],
-    const int is_shift[3]) {
+void kpt_get_dense_grid_points_by_rotations(size_t rot_grid_points[],
+                                            const int address_orig[3],
+                                            const int (*rot_reciprocal)[3][3],
+                                            const int num_rot,
+                                            const int mesh[3],
+                                            const int is_shift[3]) {
     int i;
     int address_double_orig[3], address_double[3];
 
@@ -235,7 +234,7 @@ void kpt_get_dense_grid_points_by_rotations(
 
 void kpt_get_dense_BZ_grid_points_by_rotations(
     size_t rot_grid_points[], const int address_orig[3],
-    SPGCONST int (*rot_reciprocal)[3][3], const int num_rot, const int mesh[3],
+    const int (*rot_reciprocal)[3][3], const int num_rot, const int mesh[3],
     const int is_shift[3], const size_t bz_map[]) {
     int i;
     int address_double_orig[3], address_double[3], bzmesh[3];
@@ -253,11 +252,11 @@ void kpt_get_dense_BZ_grid_points_by_rotations(
 }
 
 int kpt_relocate_BZ_grid_address(int bz_grid_address[][3], int bz_map[],
-                                 SPGCONST int grid_address[][3],
-                                 const int mesh[3],
-                                 SPGCONST double rec_lattice[3][3],
+                                 const int grid_address[][3], const int mesh[3],
+                                 const double rec_lattice[3][3],
                                  const int is_shift[3]) {
-    int i, num_bz_map, num_bzgp;
+    int num_bzgp;
+    size_t i, num_bz_map;
     size_t *dense_bz_map;
 
     num_bz_map = mesh[0] * mesh[1] * mesh[2] * 8;
@@ -286,12 +285,9 @@ int kpt_relocate_BZ_grid_address(int bz_grid_address[][3], int bz_map[],
     return num_bzgp;
 }
 
-size_t kpt_relocate_dense_BZ_grid_address(int bz_grid_address[][3],
-                                          size_t bz_map[],
-                                          SPGCONST int grid_address[][3],
-                                          const int mesh[3],
-                                          SPGCONST double rec_lattice[3][3],
-                                          const int is_shift[3]) {
+size_t kpt_relocate_dense_BZ_grid_address(
+    int bz_grid_address[][3], size_t bz_map[], const int grid_address[][3],
+    const int mesh[3], const double rec_lattice[3][3], const int is_shift[3]) {
     return relocate_dense_BZ_grid_address(bz_grid_address, bz_map, grid_address,
                                           mesh, rec_lattice, is_shift);
 }
@@ -304,7 +300,7 @@ MatINT *kpt_get_point_group_reciprocal(const MatINT *rotations,
 MatINT *kpt_get_point_group_reciprocal_with_q(const MatINT *rot_reciprocal,
                                               const double symprec,
                                               const size_t num_q,
-                                              SPGCONST double qpoints[][3]) {
+                                              const double qpoints[][3]) {
     return get_point_group_reciprocal_with_q(rot_reciprocal, symprec, num_q,
                                              qpoints);
 }
@@ -315,7 +311,7 @@ static MatINT *get_point_group_reciprocal(const MatINT *rotations,
     int i, j, num_rot;
     MatINT *rot_reciprocal, *rot_return;
     int *unique_rot;
-    SPGCONST int inversion[3][3] = {{-1, 0, 0}, {0, -1, 0}, {0, 0, -1}};
+    const int inversion[3][3] = {{-1, 0, 0}, {0, -1, 0}, {0, 0, -1}};
 
     rot_reciprocal = NULL;
     rot_return = NULL;
@@ -384,8 +380,9 @@ static MatINT *get_point_group_reciprocal(const MatINT *rotations,
 static MatINT *get_point_group_reciprocal_with_q(const MatINT *rot_reciprocal,
                                                  const double symprec,
                                                  const size_t num_q,
-                                                 SPGCONST double qpoints[][3]) {
-    int i, j, k, l, is_all_ok, num_rot;
+                                                 const double qpoints[][3]) {
+    int i, l, is_all_ok, num_rot;
+    size_t j, k;
     int *ir_rot;
     double q_rot[3], diff[3];
     MatINT *rot_reciprocal_q;
@@ -471,15 +468,14 @@ static size_t get_dense_ir_reciprocal_mesh_normal(
     /* grid: reducible grid points */
     /* ir_mapping_table: the mapping from each point to ir-point. */
 
-    long i;
-    size_t grid_point_rot;
+    size_t i, grid_point_rot;
     int j;
     int address_double[3], address_double_rot[3];
 
     kgd_get_all_grid_addresses(grid_address, mesh);
 
 #pragma omp parallel for private(j, grid_point_rot, address_double, \
-                                 address_double_rot)
+                                     address_double_rot)
     for (i = 0; i < mesh[0] * mesh[1] * (size_t)(mesh[2]); i++) {
         kgd_get_grid_address_double_mesh(address_double, grid_address[i], mesh,
                                          is_shift);
@@ -506,8 +502,7 @@ static size_t get_dense_ir_reciprocal_mesh_normal(
 static size_t get_dense_ir_reciprocal_mesh_distortion(
     int grid_address[][3], size_t ir_mapping_table[], const int mesh[3],
     const int is_shift[3], const MatINT *rot_reciprocal) {
-    long i;
-    size_t grid_point_rot;
+    size_t i, grid_point_rot;
     int j, k, indivisible;
     int address_double[3], address_double_rot[3];
     long long_address_double[3], long_address_double_rot[3], divisor[3];
@@ -521,9 +516,9 @@ static size_t get_dense_ir_reciprocal_mesh_distortion(
         divisor[j] = mesh[(j + 1) % 3] * mesh[(j + 2) % 3];
     }
 
-#pragma omp parallel for private(j, k, grid_point_rot, address_double,    \
-                                 address_double_rot, long_address_double, \
-                                 long_address_double_rot)
+#pragma omp parallel for private(j, k, grid_point_rot, address_double,        \
+                                     address_double_rot, long_address_double, \
+                                     long_address_double_rot)
     for (i = 0; i < mesh[0] * mesh[1] * (size_t)(mesh[2]); i++) {
         kgd_get_grid_address_double_mesh(address_double, grid_address[i], mesh,
                                          is_shift);
@@ -573,8 +568,7 @@ static size_t get_dense_ir_reciprocal_mesh_distortion(
 }
 
 static size_t get_dense_num_ir(size_t ir_mapping_table[], const int mesh[3]) {
-    long i;
-    size_t num_ir;
+    size_t i, num_ir;
 
     num_ir = 0;
 
@@ -594,12 +588,9 @@ static size_t get_dense_num_ir(size_t ir_mapping_table[], const int mesh[3]) {
     return num_ir;
 }
 
-static size_t relocate_dense_BZ_grid_address(int bz_grid_address[][3],
-                                             size_t bz_map[],
-                                             SPGCONST int grid_address[][3],
-                                             const int mesh[3],
-                                             SPGCONST double rec_lattice[3][3],
-                                             const int is_shift[3]) {
+static size_t relocate_dense_BZ_grid_address(
+    int bz_grid_address[][3], size_t bz_map[], const int grid_address[][3],
+    const int mesh[3], const double rec_lattice[3][3], const int is_shift[3]) {
     double tolerance, min_distance;
     double q_vector[3], distance[KPT_NUM_BZ_SEARCH_SPACE];
     int bzmesh[3], bz_address_double[3];
@@ -669,7 +660,7 @@ static size_t relocate_dense_BZ_grid_address(int bz_grid_address[][3],
     return boundary_num_gp + total_num_gp;
 }
 
-static double get_tolerance_for_BZ_reduction(SPGCONST double rec_lattice[3][3],
+static double get_tolerance_for_BZ_reduction(const double rec_lattice[3][3],
                                              const int mesh[3]) {
     int i, j;
     double tolerance;
