@@ -52,35 +52,33 @@ size_t kpt_get_dense_irreducible_reciprocal_mesh(int grid_address[][3],
 int kpt_get_stabilized_reciprocal_mesh(
     int grid_address[][3], int ir_mapping_table[], const int mesh[3],
     const int is_shift[3], const int is_time_reversal, const MatINT *rotations,
-    const size_t num_q, SPGCONST double qpoints[][3]);
+    const size_t num_q, const double qpoints[][3]);
 size_t kpt_get_dense_stabilized_reciprocal_mesh(
     int grid_address[][3], size_t ir_mapping_table[], const int mesh[3],
     const int is_shift[3], const int is_time_reversal, const MatINT *rotations,
-    const size_t num_q, SPGCONST double qpoints[][3]);
-void kpt_get_dense_grid_points_by_rotations(
-    size_t rot_grid_points[], const int address_orig[3],
-    SPGCONST int (*rot_reciprocal)[3][3], const int num_rot, const int mesh[3],
-    const int is_shift[3]);
+    const size_t num_q, const double qpoints[][3]);
+void kpt_get_dense_grid_points_by_rotations(size_t rot_grid_points[],
+                                            const int address_orig[3],
+                                            const int (*rot_reciprocal)[3][3],
+                                            const int num_rot,
+                                            const int mesh[3],
+                                            const int is_shift[3]);
 void kpt_get_dense_BZ_grid_points_by_rotations(
     size_t rot_grid_points[], const int address_orig[3],
-    SPGCONST int (*rot_reciprocal)[3][3], const int num_rot, const int mesh[3],
+    const int (*rot_reciprocal)[3][3], const int num_rot, const int mesh[3],
     const int is_shift[3], const size_t bz_map[]);
 int kpt_relocate_BZ_grid_address(int bz_grid_address[][3], int bz_map[],
-                                 SPGCONST int grid_address[][3],
-                                 const int mesh[3],
-                                 SPGCONST double rec_lattice[3][3],
+                                 const int grid_address[][3], const int mesh[3],
+                                 const double rec_lattice[3][3],
                                  const int is_shift[3]);
-size_t kpt_relocate_dense_BZ_grid_address(int bz_grid_address[][3],
-                                          size_t bz_map[],
-                                          SPGCONST int grid_address[][3],
-                                          const int mesh[3],
-                                          SPGCONST double rec_lattice[3][3],
-                                          const int is_shift[3]);
+size_t kpt_relocate_dense_BZ_grid_address(
+    int bz_grid_address[][3], size_t bz_map[], const int grid_address[][3],
+    const int mesh[3], const double rec_lattice[3][3], const int is_shift[3]);
 MatINT *kpt_get_point_group_reciprocal(const MatINT *rotations,
                                        const int is_time_reversal);
 MatINT *kpt_get_point_group_reciprocal_with_q(const MatINT *rot_reciprocal,
                                               const double symprec,
                                               const size_t num_q,
-                                              SPGCONST double qpoints[][3]);
+                                              const double qpoints[][3]);
 
 #endif
