@@ -34,6 +34,7 @@
 
 #include "magnetic_spacegroup.h"
 
+#include <math.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -46,8 +47,7 @@
 
 static int get_reference_space_group(Spacegroup **ref_sg,
                                      MagneticSymmetry **changed_symmetry,
-                                     SPGCONST double tmat[3][3],
-                                     SPGCONST double shift[3],
+                                     double tmat[3][3], double shift[3],
                                      const MagneticSymmetry *magnetic_symmetry,
                                      const double symprec);
 static Symmetry *get_family_space_group_with_magnetic_symmetry(
@@ -66,31 +66,30 @@ static int get_magnetic_space_group_type(
 static MagneticSymmetry *get_representative(
     const MagneticSymmetry *magnetic_symmetry);
 static MagneticSymmetry *get_changed_magnetic_symmetry(
-    SPGCONST double tmat[3][3], SPGCONST double shift[3],
+    const double tmat[3][3], const double shift[3],
     const MagneticSymmetry *representative, const Symmetry *sym_xsg,
     const MagneticSymmetry *magnetic_symmetry, const double symprec);
-static VecDBL *get_changed_pure_translations(SPGCONST double tmat[3][3],
+static VecDBL *get_changed_pure_translations(const double tmat[3][3],
                                              const VecDBL *pure_trans,
                                              const double symprec);
-static int is_contained_vec(SPGCONST double v[3], const VecDBL *trans,
+static int is_contained_vec(const double v[3], const VecDBL *trans,
                             const int size, const double symprec);
-static int is_contained_mat(SPGCONST int a[3][3],
-                            const MagneticSymmetry *sym_msg, const int size);
+static int is_contained_mat(const int a[3][3], const MagneticSymmetry *sym_msg,
+                            const int size);
 static MagneticSymmetry *get_distinct_changed_magnetic_symmetry(
-    SPGCONST double tmat[3][3], SPGCONST double shift[3],
+    const double tmat[3][3], const double shift[3],
     const MagneticSymmetry *sym_msg);
 static int is_equal(const MagneticSymmetry *sym1, const MagneticSymmetry *sym2,
                     const double symprec);
-void get_rigid_rotation(double rigid_rot[3][3], SPGCONST double lattice[3][3],
-                        SPGCONST double tmat[3][3],
-                        SPGCONST Spacegroup *ref_sg);
+void get_rigid_rotation(double rigid_rot[3][3], const double lattice[3][3],
+                        const double tmat[3][3], const Spacegroup *ref_sg);
 
 /******************************************************************************/
 
 /// @brief Identify magnetic space-group type with database
 /// If failed, return NULL.
 MagneticDataset *msg_identify_magnetic_space_group_type(
-    SPGCONST double lattice[3][3], const MagneticSymmetry *magnetic_symmetry,
+    const double lattice[3][3], const MagneticSymmetry *magnetic_symmetry,
     const double symprec) {
     int i, j, s, hall_number, uni_number, type, same;
     Spacegroup *ref_sg;
@@ -171,6 +170,12 @@ MagneticDataset *msg_identify_magnetic_space_group_type(
     }
     if (uni_number > uni_number_range[1]) {
         warning_print("Failed to match with UNI number!\n");
+        for (int i = 0; i < magnetic_symmetry->size; i++) {
+            debug_print("--- %d ---\n", i + 1);
+            debug_print_matrix_i3(magnetic_symmetry->rot[i]);
+            debug_print_vector_d3(magnetic_symmetry->trans[i]);
+            debug_print("%2d\n", magnetic_symmetry->timerev[i]);
+        }
         goto err;
     }
     debug_print("UNI number: %d\n", uni_number);
@@ -249,14 +254,14 @@ err:
 
 /* Return transformed cell. Note that site tensors do not need to be transformed
  */
-/* since they are in cartesian coordiantes. Return NULL if failed. */
+/* since they are in cartesian coordinates. Return NULL if failed. */
 /* To transform cell and site tensors with cell-size changing cases, */
 /*   1. transform `cell` to primitive */
 /*   2. compute pure translations after given transformation */
 /*   3. apply the pure translations to the primitive */
-Cell *msg_get_transformed_cell(const Cell *cell, SPGCONST double tmat[3][3],
-                               SPGCONST double origin_shift[3],
-                               SPGCONST double rigid_rot[3][3],
+Cell *msg_get_transformed_cell(const Cell *cell, const double tmat[3][3],
+                               const double origin_shift[3],
+                               const double rigid_rot[3][3],
                                const MagneticSymmetry *magnetic_symmetry,
                                const double symprec,
                                const double angle_tolerance) {
@@ -408,8 +413,7 @@ err:
 /* Return type of MSG. Return 0 if failed. */
 static int get_reference_space_group(Spacegroup **ref_sg,
                                      MagneticSymmetry **changed_symmetry,
-                                     SPGCONST double tmat[3][3],
-                                     SPGCONST double shift[3],
+                                     double tmat[3][3], double shift[3],
                                      const MagneticSymmetry *magnetic_symmetry,
                                      const double symprec) {
     int type;
@@ -439,6 +443,9 @@ static int get_reference_space_group(Spacegroup **ref_sg,
     type = get_magnetic_space_group_type(&representatives, magnetic_symmetry,
                                          sym_fsg->size, sym_xsg->size);
     debug_print("type=%d\n", type);
+    if (type == 0) {
+        goto err;
+    }
 
     /* Choose reference setting */
     /* For type-IV, use setting from Hall symbol of XSG. */
@@ -711,7 +718,7 @@ static MagneticSymmetry *get_representative(
 /* If failed, return NULL. */
 /* Be careful the correspondence: tmat = spacegroup->bravais_lattice^-1 */
 static MagneticSymmetry *get_changed_magnetic_symmetry(
-    SPGCONST double tmat[3][3], SPGCONST double shift[3],
+    const double tmat[3][3], const double shift[3],
     const MagneticSymmetry *representatives, const Symmetry *sym_xsg,
     const MagneticSymmetry *magnetic_symmetry, const double symprec) {
     int size, num_factors, num_sym, i, j, k;
@@ -829,7 +836,7 @@ err:
 
 /* (I, w) = (tmat, shift)^-1 (I, w_std) (tmat, shift) */
 /* w_std = tmat @ w */
-static VecDBL *get_changed_pure_translations(SPGCONST double tmat[3][3],
+static VecDBL *get_changed_pure_translations(const double tmat[3][3],
                                              const VecDBL *pure_trans,
                                              const double symprec) {
     int size, count, denominator, i, n0, n1, n2, s, t, ok;
@@ -918,7 +925,7 @@ err:
 }
 
 /* Return 1 iff `v` is contained in `trans`. */
-static int is_contained_vec(SPGCONST double v[3], const VecDBL *trans,
+static int is_contained_vec(const double v[3], const VecDBL *trans,
                             const int size, const double symprec) {
     int i, s, equivalent;
 
@@ -937,8 +944,8 @@ static int is_contained_vec(SPGCONST double v[3], const VecDBL *trans,
 }
 
 /* Return 1 iff `a` is contained in `sym_msg->rot`. */
-static int is_contained_mat(SPGCONST int a[3][3],
-                            const MagneticSymmetry *sym_msg, const int size) {
+static int is_contained_mat(const int a[3][3], const MagneticSymmetry *sym_msg,
+                            const int size) {
     int i;
     for (i = 0; i < size; i++) {
         if (mat_check_identity_matrix_i3(a, sym_msg->rot[i])) {
@@ -953,7 +960,7 @@ static int is_contained_mat(SPGCONST int a[3][3],
 /* x_std = (tmat, shift) x */
 /* (W, w) -> (tmat, shift) (W, w) (tmat, shift)^-1 */
 static MagneticSymmetry *get_distinct_changed_magnetic_symmetry(
-    SPGCONST double tmat[3][3], SPGCONST double shift[3],
+    const double tmat[3][3], const double shift[3],
     const MagneticSymmetry *sym_msg) {
     int i;
     MagneticSymmetry *changed;
@@ -1004,9 +1011,12 @@ static int is_equal(const MagneticSymmetry *sym1, const MagneticSymmetry *sym2,
         found = 0;
         for (j = 0; j < sym2->size; j++) {
             if (mat_check_identity_matrix_i3(sym1->rot[i], sym2->rot[j]) &&
-                mat_Dmod1(sym1->trans[i][0] - sym2->trans[j][0]) < symprec &&
-                mat_Dmod1(sym1->trans[i][1] - sym2->trans[j][1]) < symprec &&
-                mat_Dmod1(sym1->trans[i][2] - sym2->trans[j][2]) < symprec &&
+                fabs(mat_rem1(sym1->trans[i][0] - sym2->trans[j][0])) <
+                    symprec &&
+                fabs(mat_rem1(sym1->trans[i][1] - sym2->trans[j][1])) <
+                    symprec &&
+                fabs(mat_rem1(sym1->trans[i][2] - sym2->trans[j][2])) <
+                    symprec &&
                 sym1->timerev[i] == sym2->timerev[j]) {
                 found = 1;
                 debug_print("sym1[%d] -> sym2[%d]\n", i, j);
@@ -1020,9 +1030,8 @@ static int is_equal(const MagneticSymmetry *sym1, const MagneticSymmetry *sym2,
     return 1;
 }
 
-void get_rigid_rotation(double rigid_rot[3][3], SPGCONST double lattice[3][3],
-                        SPGCONST double tmat[3][3],
-                        SPGCONST Spacegroup *ref_sg) {
+void get_rigid_rotation(double rigid_rot[3][3], const double lattice[3][3],
+                        const double tmat[3][3], const Spacegroup *ref_sg) {
     double ideal_latt[3][3], inv_ideal_latt[3][3], inv_latt[3][3];
     double tmat_bravais[3][3], inv_tmat_bravais[3][3];
 
