@@ -1,7 +1,7 @@
-/* Copyright (C) 2015 Atsushi Togo */
+/* Copyright (C) 2023 Atsushi Togo */
 /* All rights reserved. */
 
-/* This file is part of niggli. */
+/* This file is part of spglib. */
 
 /* Redistribution and use in source and binary forms, with or without */
 /* modification, are permitted provided that the following conditions */
@@ -15,7 +15,7 @@
 /*   the documentation and/or other materials provided with the */
 /*   distribution. */
 
-/* * Neither the name of the niggli project nor the names of its */
+/* * Neither the name of the spglib project nor the names of its */
 /*   contributors may be used to endorse or promote products derived */
 /*   from this software without specific prior written permission. */
 
@@ -34,12 +34,13 @@
 
 #include "niggli.h"
 
+#include <limits.h>
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#define NIGGLI_MAX_NUM_LOOP 100
+#include "debug.h"
 
 typedef struct {
     double A;
@@ -56,6 +57,7 @@ typedef struct {
     double *lattice;
 } NiggliParams;
 
+static int get_num_attempts();
 static NiggliParams *initialize(const double *lattice_, const double eps_);
 static void finalize(double *lattice_, NiggliParams *p);
 static int reset(NiggliParams *p);
@@ -75,9 +77,7 @@ static double *multiply_matrices(const double *A, const double *B);
 static int layer_swap_axis(NiggliParams *p, const int aperiodic_axis);
 static int step2_for_layer(NiggliParams *p);
 
-#ifdef NIGGLI_DEBUG
-#define debug_print(...) printf(__VA_ARGS__)
-static void debug_show(const int j, const NiggliParams *p);
+#ifdef SPGDEBUG
 static void debug_show(const int j, const NiggliParams *p) {
     /* int i; */
 
@@ -96,16 +96,25 @@ static void debug_show(const int j, const NiggliParams *p) {
     /* } */
 }
 #else
-#define debug_print(...)
 #define debug_show(...)
 #endif
 
-#ifdef NIGGLI_WARNING
-#include <stdio.h>
-#define warning_print(...) fprintf(stderr, __VA_ARGS__)
-#else
-#define warning_print(...)
-#endif
+int get_num_attempts() {
+    const char *num_attempts_str = getenv("SPGLIB_NUM_ATTEMPTS");
+    if (num_attempts_str != NULL) {
+        // Try to parse the string as an integer
+        char *end;
+        long num_attempts = strtol(num_attempts_str, &end, 10);
+        // If conversion fails end == num_attempts_str
+        if (end != num_attempts_str && num_attempts > 0 &&
+            num_attempts < INT_MAX)
+            return (int)num_attempts;
+        warning_print("Could not parse SPGLIB_NUM_ATTEMPTS=%s\n",
+                      num_attempts_str);
+    }
+    // Otherwise return default number of attempts
+    return 1000;
+}
 
 /*--------------------------------------------*/
 /* Version: niggli-[major].[minor].[micro] */
@@ -117,16 +126,19 @@ int niggli_get_minor_version(void) { return NIGGLI_MINOR_VERSION; }
 int niggli_get_micro_version(void) { return NIGGLI_MICRO_VERSION; }
 
 /* return 0 if failed */
-int niggli_reduce(double *lattice_, const double eps_) {
-    return periodic_niggli_reduce(lattice_, eps_, -1);
-}
-
-int periodic_niggli_reduce(double *lattice_, const double eps_,
-                           const int aperiodic_axis) {
-    int i, j, succeeded;
+// For bulk, set `aperiodic_axis=-1`
+// @note For layer group, Niggli steps are modified to maintain the non-periodic
+// axis
+//       - First, Move aperiodic axis to c
+//       - Step 2 is skipped
+//       - (Steps 5 and 6 are not modified because axis c is perpendicular to
+//       the plane)
+int niggli_reduce(double *lattice_, const double eps_,
+                  const int aperiodic_axis) {
+    int succeeded;
     NiggliParams *p;
-    int (*steps[8])(NiggliParams * p) = {step1, step2, step3, step4,
-                                         step5, step6, step7, step8};
+    int (*steps[8])(NiggliParams *p) = {step1, step2, step3, step4,
+                                        step5, step6, step7, step8};
 
     if (aperiodic_axis != -1) {
         steps[1] = step2_for_layer;
@@ -140,6 +152,7 @@ int periodic_niggli_reduce(double *lattice_, const double eps_,
     }
 
     /* Step 0 */
+    // Move aperiodic axis to c for layer
     if (!(((aperiodic_axis == 0 || aperiodic_axis == 1) &&
            layer_swap_axis(p, aperiodic_axis)) ||
           ((aperiodic_axis == -1 || aperiodic_axis == 2) &&
@@ -147,8 +160,9 @@ int periodic_niggli_reduce(double *lattice_, const double eps_,
         goto ret;
     }
 
-    for (i = 0; i < NIGGLI_MAX_NUM_LOOP; i++) {
-        for (j = 0; j < 8; j++) {
+    for (int i = 0, max_attempts = get_num_attempts(); i < max_attempts; i++) {
+        int j = 0;
+        for (; j < 8; j++) {
             if ((*steps[j])(p)) {
                 debug_show(j + 1, p);
                 if (!reset(p)) {
