@@ -330,6 +330,7 @@ static int inversion[3][3] = {
     {0, 0, -1},
 };
 
+// length of `rot_axes` should be equal to `NUM_ROT_AXES`
 static int rot_axes[][3] = {
     {1, 0, 0},   {0, 1, 0},   {0, 0, 1},   {0, 1, 1},   {1, 0, 1},
     {1, 1, 0},   {0, 1, -1},  {-1, 0, 1},  {1, -1, 0},  {1, 1, 1}, /* 10 */
@@ -348,53 +349,35 @@ static int rot_axes[][3] = {
     {3, 1, -1},  {3, -1, 1},  {3, -1, -1},
 };
 
-static int get_pointgroup_number_by_rotations(SPGCONST int rotations[][3][3],
+static int get_pointgroup_number_by_rotations(const int rotations[][3][3],
                                               const int num_rotations);
-static int get_pointgroup_number(SPGCONST PointSymmetry* pointsym);
+static int get_pointgroup_number(const PointSymmetry* pointsym);
 static int get_pointgroup_class_table(int table[10],
-                                      SPGCONST PointSymmetry* pointsym);
-static int get_rotation_type(SPGCONST int rot[3][3]);
-static int get_rotation_axis(SPGCONST int rot[3][3]);
-static int get_orthogonal_axis(int ortho_axes[], SPGCONST int proper_rot[3][3],
+                                      const PointSymmetry* pointsym);
+static int get_rotation_type(const int rot[3][3]);
+static int get_rotation_axis(const int rot[3][3]);
+static int get_orthogonal_axis(int ortho_axes[], const int proper_rot[3][3],
                                const int rot_order);
-static int laue2m(int axes[3], SPGCONST PointSymmetry* pointsym);
-static int layer_laue2m(int axes[3], SPGCONST PointSymmetry* pointsym,
+static int laue2m(int axes[3], const PointSymmetry* pointsym);
+static int layer_laue2m(int axes[3], const PointSymmetry* pointsym,
                         const int aperiodic_axis);
 
-#ifdef SPGDEBUG
-static int lauemmm(int axes[3], SPGCONST PointSymmetry* pointsym);
-static int laue4m(int axes[3], SPGCONST PointSymmetry* pointsym);
-static int laue4mmm(int axes[3], SPGCONST PointSymmetry* pointsym);
-static int laue3(int axes[3], SPGCONST PointSymmetry* pointsym);
-static int laue3m(int axes[3], SPGCONST PointSymmetry* pointsym);
-static int lauem3m(int axes[3], SPGCONST PointSymmetry* pointsym);
-#endif
-
-static int laue_one_axis(int axes[3], SPGCONST PointSymmetry* pointsym,
+static int laue_one_axis(int axes[3], const PointSymmetry* pointsym,
                          const int rot_order);
-static int lauennn(int axes[3], SPGCONST PointSymmetry* pointsym,
+static int lauennn(int axes[3], const PointSymmetry* pointsym,
                    const int rot_order, const int aperiodic_axis);
-static int get_axes(int axes[3], const Laue laue,
-                    SPGCONST PointSymmetry* pointsym, const int aperiodic_axis);
-static void get_proper_rotation(int prop_rot[3][3], SPGCONST int rot[3][3]);
+static int get_axes(int axes[3], const Laue laue, const PointSymmetry* pointsym,
+                    const int aperiodic_axis);
+static void get_proper_rotation(int prop_rot[3][3], const int rot[3][3]);
 static void set_transformation_matrix(int tmat[3][3], const int axes[3]);
 static int is_exist_axis(const int axis_vec[3], const int axis_index);
 static void sort_axes(int axes[3]);
 static void layer_check_and_sort_axes(int axes[3], const int aperiodic_axis);
 
-/* Return pointgroup.number = 0 if failed */
 Pointgroup ptg_get_transformation_matrix(int transform_mat[3][3],
-                                         SPGCONST int rotations[][3][3],
-                                         const int num_rotations) {
-    return ptg_get_layer_transformation_matrix(transform_mat, rotations,
-                                               num_rotations, -1);
-}
-
-/* Layer group does not have cubic point groups */
-Pointgroup ptg_get_layer_transformation_matrix(int transform_mat[3][3],
-                                               SPGCONST int rotations[][3][3],
-                                               const int num_rotations,
-                                               const int aperiodic_axis) {
+                                         const int rotations[][3][3],
+                                         const int num_rotations,
+                                         const int aperiodic_axis) {
     int i, j, pg_num;
     int axes[3];
     PointSymmetry pointsym;
@@ -410,7 +393,9 @@ Pointgroup ptg_get_layer_transformation_matrix(int transform_mat[3][3],
 
     pg_num = get_pointgroup_number_by_rotations(rotations, num_rotations);
 
+    // Layer group does not have cubic point groups (28 <= pg_num < 32)
     if (pg_num > 0 && (aperiodic_axis == -1 || pg_num < 28)) {
+        // Based on step (c) of R. W. Grosse-Kunstleve (1999)
         pointgroup = ptg_get_pointgroup(pg_num);
         pointsym = ptg_get_pointsymmetry(rotations, num_rotations);
         get_axes(axes, pointgroup.laue, &pointsym, aperiodic_axis);
@@ -451,7 +436,8 @@ Pointgroup ptg_get_pointgroup(const int pointgroup_number) {
     return pointgroup;
 }
 
-PointSymmetry ptg_get_pointsymmetry(SPGCONST int rotations[][3][3],
+// @brief Construct PointSymmetry from given `rotations`
+PointSymmetry ptg_get_pointsymmetry(const int rotations[][3][3],
                                     const int num_rotations) {
     int i, j;
     PointSymmetry pointsym;
@@ -471,7 +457,7 @@ PointSymmetry ptg_get_pointsymmetry(SPGCONST int rotations[][3][3],
     return pointsym;
 }
 
-static int get_pointgroup_number_by_rotations(SPGCONST int rotations[][3][3],
+static int get_pointgroup_number_by_rotations(const int rotations[][3][3],
                                               const int num_rotations) {
     PointSymmetry pointsym;
 
@@ -479,7 +465,7 @@ static int get_pointgroup_number_by_rotations(SPGCONST int rotations[][3][3],
     return get_pointgroup_number(&pointsym);
 }
 
-static int get_pointgroup_number(SPGCONST PointSymmetry* pointsym) {
+static int get_pointgroup_number(const PointSymmetry* pointsym) {
     int i, j, pg_num, counter;
     int table[10];
     PointgroupType pointgroup_type;
@@ -512,8 +498,12 @@ end:
     return pg_num;
 }
 
+// @brief Return counts of types of rotations
+// @param[out] table counts of {-6, -4, -3, -2, 1, 1, 2, 3, 4, 6}-fold rotations
+// or roto-rotations
+// @param[in] pointsym
 static int get_pointgroup_class_table(int table[10],
-                                      SPGCONST PointSymmetry* pointsym) {
+                                      const PointSymmetry* pointsym) {
     /* Look-up table */
     /* Operation   -6 -4 -3 -2 -1  1  2  3  4  6 */
     /* Trace     -  2 -1  0  1 -3  3 -1  0  1  2 */
@@ -552,7 +542,7 @@ err:
     return 0;
 }
 
-static int get_rotation_type(SPGCONST int rot[3][3]) {
+static int get_rotation_type(const int rot[3][3]) {
     int rot_type;
 
     if (mat_get_determinant_i3(rot) == -1) {
@@ -602,14 +592,20 @@ static int get_rotation_type(SPGCONST int rot[3][3]) {
     return rot_type;
 }
 
-static int get_axes(int axes[3], const Laue laue,
-                    SPGCONST PointSymmetry* pointsym,
+// @brief Get conventional axes for point group `pointsym`
+// @note For layer group, Laue class 2/m and mmm need a special care
+// @param[out] axes three indices of `rot_axes`. If they are larger than
+//             NUM_ROT_AXES, it represents the negative direction.
+// @param[in] laue
+// @param[in] pointsym
+// @param[in] aperiodic_axis
+static int get_axes(int axes[3], const Laue laue, const PointSymmetry* pointsym,
                     const int aperiodic_axis) {
     switch (laue) {
         case LAUE1:
-            axes[0] = 0;
-            axes[1] = 1;
-            axes[2] = 2;
+            axes[0] = 0;  // {1, 0, 0}
+            axes[1] = 1;  // {0, 1, 0}
+            axes[2] = 2;  // {0, 0, 1}
             break;
         case LAUE2M:
             if (aperiodic_axis == -1) {
@@ -652,7 +648,7 @@ static int get_axes(int axes[3], const Laue laue,
     return 1;
 }
 
-static int laue2m(int axes[3], SPGCONST PointSymmetry* pointsym) {
+static int laue2m(int axes[3], const PointSymmetry* pointsym) {
     int i, num_ortho_axis, norm, min_norm, is_found;
     int prop_rot[3][3];
     int ortho_axes[NUM_ROT_AXES];
@@ -670,7 +666,7 @@ static int laue2m(int axes[3], SPGCONST PointSymmetry* pointsym) {
             continue;
         }
 
-        /* The first axis */
+        /* The first axis (unique axis b) */
         axes[1] = get_rotation_axis(prop_rot);
         break;
     }
@@ -685,7 +681,7 @@ static int laue2m(int axes[3], SPGCONST PointSymmetry* pointsym) {
     is_found = 0;
     for (i = 0; i < num_ortho_axis; i++) {
         norm = mat_norm_squared_i3(rot_axes[ortho_axes[i]]);
-        if (norm < min_norm - ZERO_PREC) {
+        if (norm < min_norm) {
             min_norm = norm;
             axes[0] = ortho_axes[i];
             is_found = 1;
@@ -700,7 +696,7 @@ static int laue2m(int axes[3], SPGCONST PointSymmetry* pointsym) {
     is_found = 0;
     for (i = 0; i < num_ortho_axis; i++) {
         norm = mat_norm_squared_i3(rot_axes[ortho_axes[i]]);
-        if ((norm < min_norm - ZERO_PREC) && (ortho_axes[i] != axes[0])) {
+        if ((norm < min_norm) && (ortho_axes[i] != axes[0])) {
             min_norm = norm;
             axes[2] = ortho_axes[i];
             is_found = 1;
@@ -727,7 +723,9 @@ err:
     return 0;
 }
 
-static int layer_laue2m(int axes[3], SPGCONST PointSymmetry* pointsym,
+// @note The two-fold axis is set to axis-a. Axes b and c forms the periodic
+// plane.
+static int layer_laue2m(int axes[3], const PointSymmetry* pointsym,
                         const int aperiodic_axis) {
     int i, num_ortho_axis, norm, min_norm, is_found;
     int prop_rot[3][3];
@@ -761,7 +759,7 @@ static int layer_laue2m(int axes[3], SPGCONST PointSymmetry* pointsym,
         is_found = 0;
         for (i = 0; i < num_ortho_axis; i++) {
             norm = mat_norm_squared_i3(rot_axes[ortho_axes[i]]);
-            if (norm < min_norm - ZERO_PREC) {
+            if (norm < min_norm) {
                 min_norm = norm;
                 axes[1] = ortho_axes[i];
                 is_found = 1;
@@ -776,7 +774,7 @@ static int layer_laue2m(int axes[3], SPGCONST PointSymmetry* pointsym,
         is_found = 0;
         for (i = 0; i < num_ortho_axis; i++) {
             norm = mat_norm_squared_i3(rot_axes[ortho_axes[i]]);
-            if ((norm < min_norm - ZERO_PREC) && (ortho_axes[i] != axes[1])) {
+            if ((norm < min_norm) && (ortho_axes[i] != axes[1])) {
                 min_norm = norm;
                 axes[2] = ortho_axes[i];
                 is_found = 1;
@@ -793,7 +791,7 @@ static int layer_laue2m(int axes[3], SPGCONST PointSymmetry* pointsym,
         for (i = 0; i < num_ortho_axis; i++) {
             if (rot_axes[ortho_axes[i]][aperiodic_axis] == 0) {
                 norm = mat_norm_squared_i3(rot_axes[ortho_axes[i]]);
-                if (norm < min_norm - ZERO_PREC) {
+                if (norm < min_norm) {
                     min_norm = norm;
                     axes[1] = ortho_axes[i];
                     is_found = 1;
@@ -811,7 +809,7 @@ static int layer_laue2m(int axes[3], SPGCONST PointSymmetry* pointsym,
             if (rot_axes[ortho_axes[i]][aperiodic_axis] == 1 ||
                 rot_axes[ortho_axes[i]][aperiodic_axis] == -1) {
                 norm = mat_norm_squared_i3(rot_axes[ortho_axes[i]]);
-                if (norm < min_norm - ZERO_PREC) {
+                if (norm < min_norm) {
                     min_norm = norm;
                     axes[2] = ortho_axes[i];
                     is_found = 1;
@@ -833,330 +831,8 @@ err:
     return 0;
 }
 
-#ifdef SPGDEBUG
-static int lauemmm(int axes[3], SPGCONST PointSymmetry* pointsym) {
-    int i, count, axis;
-    int prop_rot[3][3];
-
-    for (i = 0; i < 3; i++) {
-        axes[i] = -1;
-    }
-    count = 0;
-    for (i = 0; i < pointsym->size; i++) {
-        get_proper_rotation(prop_rot, pointsym->rot[i]);
-
-        /* Search two-fold rotation */
-        if (!(mat_get_trace_i3(prop_rot) == -1)) {
-            continue;
-        }
-
-        axis = get_rotation_axis(prop_rot);
-        if (!((axis == axes[0]) || (axis == axes[1]) || (axis == axes[2]))) {
-            axes[count] = axis;
-            count++;
-        }
-    }
-
-    sort_axes(axes);
-
-    return 1;
-}
-
-static int laue4m(int axes[3], SPGCONST PointSymmetry* pointsym) {
-    int i, num_ortho_axis, norm, min_norm, is_found, tmpval;
-    int axis_vec[3];
-    int prop_rot[3][3], t_mat[3][3];
-    int ortho_axes[NUM_ROT_AXES];
-
-    for (i = 0; i < pointsym->size; i++) {
-        get_proper_rotation(prop_rot, pointsym->rot[i]);
-
-        /* Search four-fold rotation */
-        if (mat_get_trace_i3(prop_rot) == 1) {
-            /* The first axis */
-            axes[2] = get_rotation_axis(prop_rot);
-            break;
-        }
-    }
-
-    /* The second axis */
-    num_ortho_axis = get_orthogonal_axis(ortho_axes, prop_rot, 4);
-    if (!num_ortho_axis) {
-        goto err;
-    }
-
-    min_norm = 8;
-    is_found = 0;
-    for (i = 0; i < num_ortho_axis; i++) {
-        norm = mat_norm_squared_i3(rot_axes[ortho_axes[i]]);
-        if (norm < min_norm - ZERO_PREC) {
-            min_norm = norm;
-            axes[0] = ortho_axes[i];
-            is_found = 1;
-        }
-    }
-    if (!is_found) {
-        goto err;
-    }
-
-    /* The third axis */
-    mat_multiply_matrix_vector_i3(axis_vec, prop_rot, rot_axes[axes[0]]);
-    is_found = 0;
-    for (i = 0; i < NUM_ROT_AXES; i++) {
-        if (is_exist_axis(axis_vec, i)) {
-            is_found = 1;
-            axes[1] = i;
-            break;
-        }
-    }
-    if (!is_found) {
-        goto err;
-    }
-
-    set_transformation_matrix(t_mat, axes);
-    if (mat_get_determinant_i3(t_mat) < 0) {
-        tmpval = axes[0];
-        axes[0] = axes[1];
-        axes[1] = tmpval;
-    }
-
-    return 1;
-
-err:
-    return 0;
-}
-
-static int laue4mmm(int axes[3], SPGCONST PointSymmetry* pointsym) {
-    int i, is_found, tmpval, axis;
-    int prop_rot[3][3], prop_rot2[3][3], t_mat[3][3];
-    int axis_vec[3];
-
-    for (i = 0; i < pointsym->size; i++) {
-        get_proper_rotation(prop_rot, pointsym->rot[i]);
-
-        /* Search four-fold rotation */
-        if (mat_get_trace_i3(prop_rot) == 1) {
-            /* The first axis */
-            axes[2] = get_rotation_axis(prop_rot);
-            break;
-        }
-    }
-
-    is_found = 0;
-    for (i = 0; i < pointsym->size; i++) {
-        get_proper_rotation(prop_rot2, pointsym->rot[i]);
-
-        /* Search two-fold rotation */
-        if (!(mat_get_trace_i3(prop_rot2) == -1)) {
-            continue;
-        }
-
-        /* The second axis */
-        axis = get_rotation_axis(prop_rot2);
-        if (!(axis == axes[2])) {
-            axes[0] = axis;
-            is_found = 1;
-            break;
-        }
-    }
-    if (!is_found) {
-        goto err;
-    }
-
-    /* The third axis */
-    mat_multiply_matrix_vector_i3(axis_vec, prop_rot, rot_axes[axes[0]]);
-    is_found = 0;
-    for (i = 0; i < NUM_ROT_AXES; i++) {
-        if (is_exist_axis(axis_vec, i)) {
-            is_found = 1;
-            axes[1] = i;
-            break;
-        }
-    }
-    if (!is_found) {
-        goto err;
-    }
-
-    set_transformation_matrix(t_mat, axes);
-    if (mat_get_determinant_i3(t_mat) < 0) {
-        tmpval = axes[0];
-        axes[0] = axes[1];
-        axes[1] = tmpval;
-    }
-
-    return 1;
-
-err:
-    return 0;
-}
-
-static int laue3(int axes[3], SPGCONST PointSymmetry* pointsym) {
-    int i, num_ortho_axis, norm, min_norm, is_found, tmpval;
-    int prop_rot[3][3], t_mat[3][3];
-    int axis_vec[3];
-    int ortho_axes[NUM_ROT_AXES];
-
-    for (i = 0; i < pointsym->size; i++) {
-        get_proper_rotation(prop_rot, pointsym->rot[i]);
-
-        /* Search thee-fold rotation */
-        if (mat_get_trace_i3(prop_rot) == 0) {
-            /* The first axis */
-            axes[2] = get_rotation_axis(prop_rot);
-            break;
-        }
-    }
-
-    /* The second axis */
-    num_ortho_axis = get_orthogonal_axis(ortho_axes, prop_rot, 3);
-    if (!num_ortho_axis) {
-        goto err;
-    }
-    min_norm = 8;
-    is_found = 0;
-    for (i = 0; i < num_ortho_axis; i++) {
-        norm = mat_norm_squared_i3(rot_axes[ortho_axes[i]]);
-        if (norm < min_norm - ZERO_PREC) {
-            min_norm = norm;
-            axes[0] = ortho_axes[i];
-            is_found = 1;
-        }
-    }
-    if (!is_found) {
-        goto err;
-    }
-
-    /* The third axis */
-    mat_multiply_matrix_vector_i3(axis_vec, prop_rot, rot_axes[axes[0]]);
-    is_found = 0;
-    for (i = 0; i < NUM_ROT_AXES; i++) {
-        is_found = is_exist_axis(axis_vec, i);
-        if (is_found == 1) {
-            axes[1] = i;
-            break;
-        }
-        if (is_found == -1) {
-            axes[1] = i + NUM_ROT_AXES;
-            break;
-        }
-    }
-    if (!is_found) {
-        goto err;
-    }
-
-    set_transformation_matrix(t_mat, axes);
-    if (mat_get_determinant_i3(t_mat) < 0) {
-        tmpval = axes[0];
-        axes[0] = axes[1];
-        axes[1] = tmpval;
-    }
-
-    return 1;
-
-err:
-    return 0;
-}
-
-static int laue3m(int axes[3], SPGCONST PointSymmetry* pointsym) {
-    int i, is_found, tmpval, axis;
-    int prop_rot[3][3], prop_rot2[3][3], t_mat[3][3];
-    int axis_vec[3];
-
-    for (i = 0; i < pointsym->size; i++) {
-        get_proper_rotation(prop_rot, pointsym->rot[i]);
-
-        /* Search three-fold rotation */
-        if (mat_get_trace_i3(prop_rot) == 0) {
-            /* The first axis */
-            axes[2] = get_rotation_axis(prop_rot);
-            debug_print("laue3m prop_rot\n");
-            debug_print_matrix_i3(prop_rot);
-            break;
-        }
-    }
-
-    is_found = 0;
-    for (i = 0; i < pointsym->size; i++) {
-        get_proper_rotation(prop_rot2, pointsym->rot[i]);
-
-        /* Search two-fold rotation */
-        if (!(mat_get_trace_i3(prop_rot2) == -1)) {
-            continue;
-        }
-
-        /* The second axis */
-        axis = get_rotation_axis(prop_rot2);
-        if (!(axis == axes[2])) {
-            axes[0] = axis;
-            is_found = 1;
-            break;
-        }
-    }
-    if (!is_found) {
-        goto err;
-    }
-
-    /* The third axis */
-    mat_multiply_matrix_vector_i3(axis_vec, prop_rot, rot_axes[axes[0]]);
-    is_found = 0;
-    for (i = 0; i < NUM_ROT_AXES; i++) {
-        is_found = is_exist_axis(axis_vec, i);
-        if (is_found == 1) {
-            axes[1] = i;
-            break;
-        }
-        if (is_found == -1) {
-            axes[1] = i + NUM_ROT_AXES;
-            break;
-        }
-    }
-    if (!is_found) {
-        goto err;
-    }
-
-    set_transformation_matrix(t_mat, axes);
-    if (mat_get_determinant_i3(t_mat) < 0) {
-        tmpval = axes[0];
-        axes[0] = axes[1];
-        axes[1] = tmpval;
-    }
-
-    return 1;
-
-err:
-    return 0;
-}
-
-static int lauem3m(int axes[3], SPGCONST PointSymmetry* pointsym) {
-    int i, count, axis;
-    int prop_rot[3][3];
-
-    for (i = 0; i < 3; i++) {
-        axes[i] = -1;
-    }
-    count = 0;
-    for (i = 0; i < pointsym->size; i++) {
-        get_proper_rotation(prop_rot, pointsym->rot[i]);
-
-        /* Search four-fold rotation */
-        if (!(mat_get_trace_i3(prop_rot) == 1)) {
-            continue;
-        }
-
-        axis = get_rotation_axis(prop_rot);
-        if (!((axis == axes[0]) || (axis == axes[1]) || (axis == axes[2]))) {
-            axes[count] = axis;
-            count++;
-        }
-    }
-
-    sort_axes(axes);
-
-    return 1;
-}
-#endif
-
-static int laue_one_axis(int axes[3], SPGCONST PointSymmetry* pointsym,
+// For Laue classes 4/m, 4/mmm, -3, -3/m, 6/m, 6/mmm
+static int laue_one_axis(int axes[3], const PointSymmetry* pointsym,
                          const int rot_order) {
     int i, j, num_ortho_axis, det, is_found, tmpval;
     int axis_vec[3], tmp_axes[3];
@@ -1171,7 +847,7 @@ static int laue_one_axis(int axes[3], SPGCONST PointSymmetry* pointsym,
         /* Search four-fold rotation */
         if (rot_order == 4) {
             if (mat_get_trace_i3(prop_rot) == 1) {
-                /* The first axis */
+                /* The first axis (c axis) */
                 axes[2] = get_rotation_axis(prop_rot);
                 break;
             }
@@ -1180,7 +856,7 @@ static int laue_one_axis(int axes[3], SPGCONST PointSymmetry* pointsym,
         /* Search three-fold rotation */
         if (rot_order == 3) {
             if (mat_get_trace_i3(prop_rot) == 0) {
-                /* The first axis */
+                /* The first axis (c axis) */
                 axes[2] = get_rotation_axis(prop_rot);
                 break;
             }
@@ -1245,7 +921,8 @@ end:
     return 1;
 }
 
-static int lauennn(int axes[3], SPGCONST PointSymmetry* pointsym,
+// For Laue classes mmm, m-3, m-3m
+static int lauennn(int axes[3], const PointSymmetry* pointsym,
                    const int rot_order, const int aperiodic_axis) {
     int i, count, axis;
     int prop_rot[3][3];
@@ -1279,7 +956,7 @@ static int lauennn(int axes[3], SPGCONST PointSymmetry* pointsym,
     return 1;
 }
 
-static int get_rotation_axis(SPGCONST int proper_rot[3][3]) {
+static int get_rotation_axis(const int proper_rot[3][3]) {
     int i, axis = -1;
     int vec[3];
 
@@ -1299,16 +976,19 @@ static int get_rotation_axis(SPGCONST int proper_rot[3][3]) {
     }
 
 end:
-#ifdef SPGDEBUG
     if (axis == -1) {
-        printf("rotation axis could not be found.\n");
+        debug_print("rotation axis could not be found.\n");
     }
-#endif
 
     return axis;
 }
 
-static int get_orthogonal_axis(int ortho_axes[], SPGCONST int proper_rot[3][3],
+// Output indices of `rot_axes` orthogonal to the axis of `proper_rot`
+// @param[out] ortho_axes indices of `rot_axes`
+// @param[in] proper_rot Proper rotation
+// @param[in] rot_order
+// @return Size of orthogonal axes
+static int get_orthogonal_axis(int ortho_axes[], const int proper_rot[3][3],
                                const int rot_order) {
     int i, num_ortho_axis;
     int vec[3];
@@ -1316,6 +996,7 @@ static int get_orthogonal_axis(int ortho_axes[], SPGCONST int proper_rot[3][3],
 
     num_ortho_axis = 0;
 
+    // sum_rot = proper_rot + ... + proper_rot^rot_order
     mat_copy_matrix_i3(sum_rot, identity);
     mat_copy_matrix_i3(rot, identity);
     for (i = 0; i < rot_order - 1; i++) {
@@ -1324,6 +1005,7 @@ static int get_orthogonal_axis(int ortho_axes[], SPGCONST int proper_rot[3][3],
     }
 
     for (i = 0; i < NUM_ROT_AXES; i++) {
+        // Kernel of `sum_rot` is always orthogonal to the axis of `proper_rot`
         mat_multiply_matrix_vector_i3(vec, sum_rot, rot_axes[i]);
         if (vec[0] == 0 && vec[1] == 0 && vec[2] == 0) {
             ortho_axes[num_ortho_axis] = i;
@@ -1334,7 +1016,8 @@ static int get_orthogonal_axis(int ortho_axes[], SPGCONST int proper_rot[3][3],
     return num_ortho_axis;
 }
 
-static void get_proper_rotation(int prop_rot[3][3], SPGCONST int rot[3][3]) {
+// @brief If `rot` is improper, output `rot` with inversion.
+static void get_proper_rotation(int prop_rot[3][3], const int rot[3][3]) {
     if (mat_get_determinant_i3(rot) == -1) {
         mat_multiply_matrix_i3(prop_rot, inversion, rot);
     } else {
@@ -1342,6 +1025,7 @@ static void get_proper_rotation(int prop_rot[3][3], SPGCONST int rot[3][3]) {
     }
 }
 
+// @brief Construct `tmat` from given indices corresponding to `rot_axes`
 static void set_transformation_matrix(int tmat[3][3], const int axes[3]) {
     int i, j, s[3];
 
@@ -1359,6 +1043,8 @@ static void set_transformation_matrix(int tmat[3][3], const int axes[3]) {
     }
 }
 
+// @brief Return 1 if axis_vec == rot_axes[axis_index],
+//        -1 if axis_vec == -rot_axes[axis_index], otherwise return 0.
 static int is_exist_axis(const int axis_vec[3], const int axis_index) {
     if ((axis_vec[0] == rot_axes[axis_index][0]) &&
         (axis_vec[1] == rot_axes[axis_index][1]) &&
@@ -1377,19 +1063,19 @@ static void sort_axes(int axes[3]) {
     int axis;
     int t_mat[3][3];
 
-    if (axes[1] > axes[2] + ZERO_PREC) {
+    if (axes[1] > axes[2]) {
         axis = axes[1];
         axes[1] = axes[2];
         axes[2] = axis;
     }
 
-    if (axes[0] > axes[1] + ZERO_PREC) {
+    if (axes[0] > axes[1]) {
         axis = axes[0];
         axes[0] = axes[1];
         axes[1] = axis;
     }
 
-    if (axes[1] > axes[2] + ZERO_PREC) {
+    if (axes[1] > axes[2]) {
         axis = axes[1];
         axes[1] = axes[2];
         axes[2] = axis;
@@ -1403,8 +1089,8 @@ static void sort_axes(int axes[3]) {
     }
 }
 
-/* Warning when rot_axes[axes[i]][aperiodic_axis] == -2, -3, 2, 3 */
-/* I am not sure if this would ever happen. */
+// Sort two-fold axes for Laue class mmm for layer group.
+// Non-periodic axis is maintained to be c-axis.
 static void layer_check_and_sort_axes(int axes[3], const int aperiodic_axis) {
     int i, lattice_rank, arank, axis, axis_i;
     int t_mat[3][3];
@@ -1433,6 +1119,8 @@ static void layer_check_and_sort_axes(int axes[3], const int aperiodic_axis) {
             axes[1] = axis;
         }
     } else {
+        // Warning when rot_axes[axes[i]][aperiodic_axis] == -2, -3, 2, 3
+        // I am not sure if this would ever happen.
         warning_print("spglib: Invalid axes were found ");
         warning_print("(line %d, %s).\n", __LINE__, __FILE__);
         for (i = 0; i < 3; i++) {
