@@ -63,7 +63,7 @@ static int relative_axes[][3] = {
 static int identity[3][3] = {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}};
 
 static int get_index_with_least_atoms(const Cell *cell);
-static VecDBL *get_translation(SPGCONST int rot[3][3], const Cell *cell,
+static VecDBL *get_translation(const int rot[3][3], const Cell *cell,
                                const double symprec, const int is_identity);
 static Symmetry *get_operations(const Cell *primitive, const double symprec,
                                 const double angle_symprec);
@@ -73,39 +73,39 @@ static Symmetry *reduce_operation(const Cell *primitive,
                                   const double angle_symprec,
                                   const int is_pure_trans);
 static int search_translation_part(int atoms_found[], const Cell *cell,
-                                   SPGCONST int rot[3][3],
+                                   const int rot[3][3],
                                    const int min_atom_index,
                                    const double origin[3], const double symprec,
                                    const int is_identity);
 static int search_pure_translations(int atoms_found[], const Cell *cell,
                                     const double trans[3],
                                     const double symprec);
-static int is_overlap_all_atoms(const double test_trans[3],
-                                SPGCONST int rot[3][3], const Cell *cell,
-                                const double symprec, const int is_identity);
+static int is_overlap_all_atoms(const double test_trans[3], const int rot[3][3],
+                                const Cell *cell, const double symprec,
+                                const int is_identity);
 static PointSymmetry transform_pointsymmetry(
-    SPGCONST PointSymmetry *point_sym_prim, SPGCONST double new_lattice[3][3],
-    SPGCONST double original_lattice[3][3]);
-static Symmetry *get_space_group_operations(SPGCONST PointSymmetry *lattice_sym,
+    const PointSymmetry *point_sym_prim, const double new_lattice[3][3],
+    const double original_lattice[3][3]);
+static Symmetry *get_space_group_operations(const PointSymmetry *lattice_sym,
                                             const Cell *primitive,
                                             const double symprec);
 static void set_axes(int axes[3][3], const int a1, const int a2, const int a3);
 static PointSymmetry get_lattice_symmetry(const Cell *cell,
                                           const double symprec,
                                           const double angle_symprec);
-static int is_identity_metric(SPGCONST double metric_rotated[3][3],
-                              SPGCONST double metric_orig[3][3],
+static int is_identity_metric(const double metric_rotated[3][3],
+                              const double metric_orig[3][3],
                               const double symprec, const double angle_symprec);
-static double get_angle(SPGCONST double metric[3][3], const int i, const int j);
+static double get_angle(const double metric[3][3], const int i, const int j);
 
 /* get_translation, search_translation_part and search_pure_translations */
 /* are duplicated to get the if statement outside the nested loops */
 /* I have not tested if it is better in efficiency. */
-static VecDBL *get_layer_translation(SPGCONST int rot[3][3], const Cell *cell,
+static VecDBL *get_layer_translation(const int rot[3][3], const Cell *cell,
                                      const double symprec,
                                      const int is_identity);
 static int search_layer_translation_part(int atoms_found[], const Cell *cell,
-                                         SPGCONST int rot[3][3],
+                                         const int rot[3][3],
                                          const int min_atom_index,
                                          const double origin[3],
                                          const double symprec,
@@ -436,7 +436,7 @@ static Symmetry *reduce_operation(const Cell *primitive,
 /* Look for the translations which satisfy the input symmetry operation. */
 /* This function is heaviest in this code. */
 /* Return NULL if failed */
-static VecDBL *get_translation(SPGCONST int rot[3][3], const Cell *cell,
+static VecDBL *get_translation(const int rot[3][3], const Cell *cell,
                                const double symprec, const int is_identity) {
     int i, j, k, min_atom_index, num_trans;
     int *is_found;
@@ -499,7 +499,7 @@ ret:
 
 /* Returns -1 on failure. */
 static int search_translation_part(int atoms_found[], const Cell *cell,
-                                   SPGCONST int rot[3][3],
+                                   const int rot[3][3],
                                    const int min_atom_index,
                                    const double origin[3], const double symprec,
                                    const int is_identity) {
@@ -606,7 +606,7 @@ static int search_pure_translations(int atoms_found[], const Cell *cell,
 /* Thoroughly confirms that a given symmetry operation is a symmetry. */
 /* This is a convenient wrapper around ovl_check_total_overlap. */
 /* -1: Error.  0: Not a symmetry.  1: Is a symmetry. */
-static int is_overlap_all_atoms(const double trans[3], SPGCONST int rot[3][3],
+static int is_overlap_all_atoms(const double trans[3], const int rot[3][3],
                                 const Cell *cell, const double symprec,
                                 const int is_identity) {
     OverlapChecker *checker;
@@ -674,7 +674,7 @@ static int get_index_with_least_atoms(const Cell *cell) {
 /* Look for the translations which satisfy the input symmetry operation. */
 /* This function is heaviest in this code. */
 /* Return NULL if failed */
-static VecDBL *get_layer_translation(SPGCONST int rot[3][3], const Cell *cell,
+static VecDBL *get_layer_translation(const int rot[3][3], const Cell *cell,
                                      const double symprec,
                                      const int is_identity) {
     int i, j, k, min_atom_index, num_trans;
@@ -740,7 +740,7 @@ ret:
 
 /* Returns -1 on failure. */
 static int search_layer_translation_part(int atoms_found[], const Cell *cell,
-                                         SPGCONST int rot[3][3],
+                                         const int rot[3][3],
                                          const int min_atom_index,
                                          const double origin[3],
                                          const double symprec,
@@ -848,7 +848,7 @@ static int search_layer_pure_translations(int atoms_found[], const Cell *cell,
 }
 
 /* Return NULL if failed */
-static Symmetry *get_space_group_operations(SPGCONST PointSymmetry *lattice_sym,
+static Symmetry *get_space_group_operations(const PointSymmetry *lattice_sym,
                                             const Cell *primitive,
                                             const double symprec) {
     int i, j, num_sym, total_num_sym;
@@ -959,14 +959,39 @@ static PointSymmetry get_lattice_symmetry(const Cell *cell,
         for (i = 0; i < 26; i++) {
             for (j = 0; j < 26; j++) {
                 for (k = 0; k < 26; k++) {
-                    /* For layer group, some rotations are not permitted. */
-                    if (aperiodic_axis != -1 &&
-                        ((aperiodic_axis == 2 && k != 2 && k != 5) ||
-                         (aperiodic_axis == 0 && i != 0 && i != 3) ||
-                         (aperiodic_axis == 1 && j != 1 && j != 4))) {
-                        continue;
-                    }
                     set_axes(axes, i, j, k);
+                    /* For layer groups, the off-diagonal elements for the
+                     * aperiodic axis are set to be zero.
+                     * Please note that for inclined aperiodic axis, some
+                     * operations will not be found */
+                    switch (aperiodic_axis) {
+                        case 2:
+                            /*    {{W_11, W_12,      0}, *
+                             * W = {W_21, W_22,      0}, *
+                             *     {   0,    0, (+/-)1}} */
+                            if (axes[0][2] || axes[1][2] || axes[2][0] ||
+                                axes[2][1])
+                                continue;
+                            break;
+                        case 0:
+                            /*    {{(+/-)1,    0,    0}, *
+                             * W = {     0, W_22, W_23}, *
+                             *     {     0, W_32, W_33}} */
+                            if (axes[0][1] || axes[0][2] || axes[1][0] ||
+                                axes[2][0])
+                                continue;
+                            break;
+                        case 1:
+                            /*    {{W_11,      0, W_13}, *
+                             * W = {   0, (+/-)1,    0}, *
+                             *     {W_31,      0, W_33}} */
+                            if (axes[0][1] || axes[1][0] || axes[1][2] ||
+                                axes[2][1])
+                                continue;
+                            break;
+                        default:
+                            break;
+                    }
                     if (!((mat_get_determinant_i3(axes) == 1) ||
                           (mat_get_determinant_i3(axes) == -1))) {
                         continue;
@@ -976,8 +1001,8 @@ static PointSymmetry get_lattice_symmetry(const Cell *cell,
 
                     if (is_identity_metric(metric, metric_orig, symprec,
                                            angle_tol)) {
-                        if ((aperiodic_axis == -1 && num_sym > 47) ||
-                            (aperiodic_axis != -1 && num_sym > 23)) {
+                        if ((aperiodic_axis == -1 && num_sym >= 48) ||
+                            (aperiodic_axis != -1 && num_sym >= 24)) {
                             warning_print(
                                 "spglib: Too many lattice symmetries was "
                                 "found.\n");
@@ -999,8 +1024,8 @@ static PointSymmetry get_lattice_symmetry(const Cell *cell,
             }
         }
 
-        if ((aperiodic_axis == -1 && num_sym < 49) ||
-            (aperiodic_axis != -1 && num_sym < 25) || angle_tol < 0) {
+        if ((aperiodic_axis == -1 && num_sym <= 48) ||
+            (aperiodic_axis != -1 && num_sym <= 24) || angle_tol < 0) {
             lattice_sym.size = num_sym;
             return transform_pointsymmetry(&lattice_sym, cell->lattice,
                                            min_lattice);
@@ -1014,8 +1039,8 @@ err:
     return lattice_sym;
 }
 
-static int is_identity_metric(SPGCONST double metric_rotated[3][3],
-                              SPGCONST double metric_orig[3][3],
+static int is_identity_metric(const double metric_rotated[3][3],
+                              const double metric_orig[3][3],
                               const double symprec,
                               const double angle_symprec) {
     int i, j, k;
@@ -1065,8 +1090,7 @@ fail:
     return 0;
 }
 
-static double get_angle(SPGCONST double metric[3][3], const int i,
-                        const int j) {
+static double get_angle(const double metric[3][3], const int i, const int j) {
     double length_i, length_j;
 
     length_i = sqrt(metric[i][i]);
@@ -1076,8 +1100,8 @@ static double get_angle(SPGCONST double metric[3][3], const int i,
 }
 
 static PointSymmetry transform_pointsymmetry(
-    SPGCONST PointSymmetry *lat_sym_orig, SPGCONST double new_lattice[3][3],
-    SPGCONST double original_lattice[3][3]) {
+    const PointSymmetry *lat_sym_orig, const double new_lattice[3][3],
+    const double original_lattice[3][3]) {
     int i, size;
     double trans_mat[3][3], inv_mat[3][3], drot[3][3];
     PointSymmetry lat_sym_new;
@@ -1107,13 +1131,11 @@ static PointSymmetry transform_pointsymmetry(
         }
     }
 
-#ifdef SPGWARNING
     if (!(lat_sym_orig->size == size)) {
         warning_print(
             "spglib: Some of point symmetry operations were dropped.");
         warning_print("(line %d, %s).\n", __LINE__, __FILE__);
     }
-#endif
 
     lat_sym_new.size = size;
     return lat_sym_new;
@@ -1122,6 +1144,8 @@ err:
     return lat_sym_new;
 }
 
+// @brief Set an integer matrix to `axes`. Three integer vectors are specified
+//        by indices of array `symmetry.c:relative_axes`.
 static void set_axes(int axes[3][3], const int a1, const int a2, const int a3) {
     int i;
     for (i = 0; i < 3; i++) {
